@@ -7,7 +7,7 @@ import logging
 
 class StudiogdoApi(object):
     """
-    Rest API to retrieve objects in a hierarchical back-end
+    Studiogdo API in python.
     """
 
     # Studiogdo URL root
@@ -58,7 +58,9 @@ class StudiogdoApi(object):
             self.append_param("ap", path)
         return self.send('get', 'prop.gdo')
 
-    def post_empty(self, form_data=None):
+    def post_empty(self, path=None, form_data=None):
+        if path:
+            self.append_param("ap", path)
         return self.send("post", "empty.gdo", form_data)
 
     def _post_facet(self, cmd, path, skeleton, facet="html5", form_data=None):
@@ -152,7 +154,5 @@ class StudiogdoApi(object):
                 self.studiogdo_cookies = response.cookies
 
             return response
-
         except:
-            msg = "studiogdo service not available"
-            return HttpResponseGone(reason=msg)
+            raise Exception("studiogdo service not available")
